@@ -25,7 +25,7 @@ class Lemmatizer(AnnotatorApproach):
     For instantiated/pretrained models, see :class:`.LemmatizerModel`.
 
     For available pretrained models please see the `Models Hub <https://nlp.johnsnowlabs.com/models?task=Lemmatization>`__.
-    For extended examples of usage, see the `Spark NLP Workshop <https://github.com/JohnSnowLabs/spark-nlp-workshop/blob/master/tutorials/Certification_Trainings/Public/2.Text_Preprocessing_with_SparkNLP_Annotators_Transformers.ipynb>`__.
+    For extended examples of usage, see the `Examples <https://github.com/JohnSnowLabs/spark-nlp/blob/master/example/python/training/italian/Train-Lemmatizer-Italian.ipynb>`__.
 
     ====================== ======================
     Input Annotation types Output Annotation type
