@@ -28,4 +28,6 @@ from sparknlp.base.token_assembler import *
 from sparknlp.base.image_assembler import *
 from sparknlp.base.audio_assembler import *
 from sparknlp.base.table_assembler import *
+from sparknlp.base.token2_chunk import *
+from sparknlp.base.date2_chunk import *
 
